==> rc-ui-lib-1.3.4.tgz: package/es/notify/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
var _excluded = ["onClose", "duration"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/* eslint-disable @typescript-eslint/naming-convention */
import React, { useCallback, useEffect, useState } from 'react';
import ReactDOM from 'react-dom';
import { extend, isObject, noop, once } from '../utils';
import Notify from './Notify';
import { resolveContainer } from '../utils/dom/getContainer';
import { lockClick } from '../toast/lock-click';
var NotifyNamespace = {};

function parseOptions(message) {
  return isObject(message) ? message : {
    message: message
  };
}

var notifyArray = []; // 同步的销毁

function syncClear() {
  var fn = notifyArray.pop();

  while (fn) {
    fn();
    lockClick(false);
    fn = notifyArray.pop();
  }
} // 针对 toast 还没弹出来就立刻销毁的情况，将销毁放到下一个 event loop 中，避免销毁失败。


function nextTickClear() {
  setTimeout(syncClear);
} // 可返回用于销毁此弹窗的方法


var show = function show(p) {
  var props = parseOptions(p);

  var interProps = _objectSpread(_objectSpread({}, NotifyNamespace.currentOptions), props);

  var _interProps$onClose = interProps.onClose,
      onClose = _interProps$onClose === void 0 ? noop : _interProps$onClose,
      duration = interProps.duration,
      restProps = _objectWithoutProperties(interProps, _excluded);

  var timer = 0;
  var userContainer = resolveContainer(props.teleport);
  var container = document.createElement('div');
  userContainer.appendChild(container);
  var destroy = noop;

  var TempNotify = function TempNotify() {
    var _useState = useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        visible = _useState2[0],
        setVisible = _useState2[1];

    destroy = function destroy() {
      setVisible(false);
      if (onClose) onClose();
    }; // clearDOM after animation


    var internalOnClosed = function internalOnClosed() {
      var unmountResult = ReactDOM.unmountComponentAtNode(container);

      if (unmountResult && container.parentNode) {
        container.parentNode.removeChild(container);
      }
    };

    var internalAfterClose = useCallback(once(function () {
      internalOnClosed();
    }), [onClose, container]);
    useEffect(function () {
      setVisible(true);
      syncClear();
      notifyArray.push(internalAfterClose);

      if (duration && +duration > 0) {
        timer = window.setTimeout(destroy, duration);
      }

      return function () {
        if (timer !== 0) {
          window.clearTimeout(timer);
        }
      };
    }, []);
    return /*#__PURE__*/React.createElement(Notify, _extends({}, restProps, {
      visible: visible,
      teleport: function teleport() {
        return container;
      },
      onClose: onClose,
      onClosed: internalOnClosed
    }));
  };

  ReactDOM.render( /*#__PURE__*/React.createElement(TempNotify, null), container);
  return destroy;
};

function defaultOptions() {
  return {
    type: 'danger',
    color: undefined,
    message: '',
    onClose: undefined,
    onClick: undefined,
    duration: 3000,
    className: '',
    lockScroll: false,
    background: undefined
  };
}

NotifyNamespace.currentOptions = defaultOptions();

var setDefaultOptions = function setDefaultOptions(options) {
  extend(NotifyNamespace.currentOptions, options);
};

var resetDefaultOptions = function resetDefaultOptions() {
  NotifyNamespace.currentOptions = defaultOptions();
};

var clear = nextTickClear;
var exportNotifyNamespace = Object.assign(Notify, {
  show: show,
  setDefaultOptions: setDefaultOptions,
  resetDefaultOptions: resetDefaultOptions,
  clear: clear
});
export default exportNotifyNamespace;
export { exportNotifyNamespace as Notify, NotifyNamespace };

==> rc-ui-lib-1.3.5.tgz: package/es/notify/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
var _excluded = ["onClose", "duration"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
/* eslint-disable @typescript-eslint/naming-convention */
import React, { useCallback, useEffect, useState } from 'react';
import ReactDOM from 'react-dom';
import { extend, isObject, noop, once } from '../utils';
import Notify from './Notify';
import { resolveContainer } from '../utils/dom/getContainer';
import { lockClick } from '../toast/lock-click';
var NotifyNamespace = {};
function parseOptions(message) {
  return isObject(message) ? message : {
    message: message
  };
}
var notifyArray = [];

// 同步的销毁
function syncClear() {
  var fn = notifyArray.pop();
  while (fn) {
    fn();
    lockClick(false);
    fn = notifyArray.pop();
  }
}

// 针对 toast 还没弹出来就立刻销毁的情况，将销毁放到下一个 event loop 中，避免销毁失败。
function nextTickClear() {
  setTimeout(syncClear);
}

// 可返回用于销毁此弹窗的方法
var show = function show(p) {
  var props = parseOptions(p);
  var interProps = _objectSpread(_objectSpread({}, NotifyNamespace.currentOptions), props);
  var _interProps$onClose = interProps.onClose,
    onClose = _interProps$onClose === void 0 ? noop : _interProps$onClose,
    duration = interProps.duration,
    restProps = _objectWithoutProperties(interProps, _excluded);
  var timer = 0;
  var userContainer = resolveContainer(props.teleport);
  var container = document.createElement('div');
  userContainer.appendChild(container);
  var destroy = noop;
  var TempNotify = function TempNotify() {
    var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      visible = _useState2[0],
      setVisible = _useState2[1];
    destroy = function destroy() {
      setVisible(false);
      if (onClose) onClose();
    };

    // clearDOM after animation
    var internalOnClosed = function internalOnClosed() {
      var unmountResult = ReactDOM.unmountComponentAtNode(container);
      if (unmountResult && container.parentNode) {
        container.parentNode.removeChild(container);
      }
    };
    var internalAfterClose = useCallback(once(function () {
      internalOnClosed();
    }), [onClose, container]);
    useEffect(function () {
      setVisible(true);
      syncClear();
      notifyArray.push(internalAfterClose);
      if (duration && +duration > 0) {
        timer = window.setTimeout(destroy, duration);
      }
      return function () {
        if (timer !== 0) {
          window.clearTimeout(timer);
        }
      };
    }, []);
    return /*#__PURE__*/React.createElement(Notify, _extends({}, restProps, {
      visible: visible,
      teleport: function teleport() {
        return container;
      },
      onClose: onClose,
      onClosed: internalOnClosed
    }));
  };
  ReactDOM.render( /*#__PURE__*/React.createElement(TempNotify, null), container);
  return destroy;
};
function defaultOptions() {
  return {
    type: 'danger',
    color: undefined,
    message: '',
    onClose: undefined,
    onClick: undefined,
    duration: 3000,
    className: '',
    lockScroll: false,
    background: undefined
  };
}
NotifyNamespace.currentOptions = defaultOptions();
var setDefaultOptions = function setDefaultOptions(options) {
  extend(NotifyNamespace.currentOptions, options);
};
var resetDefaultOptions = function resetDefaultOptions() {
  NotifyNamespace.currentOptions = defaultOptions();
};
var clear = nextTickClear;
var exportNotifyNamespace = Object.assign(Notify, {
  show: show,
  setDefaultOptions: setDefaultOptions,
  resetDefaultOptions: resetDefaultOptions,
  clear: clear
});
export default exportNotifyNamespace;
export { exportNotifyNamespace as Notify, NotifyNamespace };
